/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2013 by Tidalwave s.a.s. (http://tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.tidalwave.it
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.actor;

import javax.annotation.Nonnull;
import org.openide.modules.ModuleInstall;
import it.tidalwave.actor.spi.ActorGroupActivator;
import lombok.extern.slf4j.Slf4j;
import org.openide.modules.ModuleInfo;
import org.openide.modules.Modules;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Slf4j
public class ActorActivatorInstallSupport extends ModuleInstall
  {
    private final ActorGroupActivator actorActivator;
    
    public ActorActivatorInstallSupport()
      {
        actorActivator = new ActorGroupActivator();
        this.putProperty(ActorGroupActivator.class, actorActivator); // without this the actorActivator gets garbage collected
      }
        
    @Override
    public void restored() 
      {
        registerActors(actorActivator);
        log.info("======== Activating actors for module {}", getName());
        actorActivator.activate();
        log.info("======== Activated actors for module {}", getName());
      }

    @Override
    public void close() 
      {
        log.info("======== Deactivating actors for module {}", getName());
        actorActivator.deactivate();
        log.info("======== Deactivated actors for module {}", getName());
      }
    
    protected void registerActors (final @Nonnull ActorGroupActivator activator)
      {
      }
    
    @Nonnull
    private String getName()
      {
        final ModuleInfo info = Modules.getDefault().ownerOf(getClass());
        return String.format("%s (%s)", info.getDisplayName(), info.getCodeNameBase());
      }
  }